from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

ADJUSTED_TENOR: FieldProto
ASSET_CLASS: FieldProto
AS_OF: FieldProto
CASH_IMPACT_SECURITY: FieldProto
DESCRIPTOR: _descriptor.FileDescriptor
EFFECTIVE_DATE: FieldProto
ID: FieldProto
IDENTIFIER: FieldProto
ISSUE_DATE: FieldProto
IS_CANCELLED: FieldProto
MATURITY_DATE: FieldProto
PORTFOLIO: FieldProto
PORTFOLIO_ID: FieldProto
PORTFOLIO_NAME: FieldProto
POSITION_STATUS: FieldProto
PRICE: FieldProto
PRICE_ID: FieldProto
PRODUCT_CLASS: FieldProto
PRODUCT_TYPE: FieldProto
SECURITY: FieldProto
SECURITY_DESCRIPTION: FieldProto
SECURITY_ID: FieldProto
SETTLEMENT_DATE: FieldProto
STRATEGY: FieldProto
TAX_LOT_CLOSE_DATE: FieldProto
TAX_LOT_OPEN_DATE: FieldProto
TENOR: FieldProto
TRADE_DATE: FieldProto
TRANSACTION_TYPE: FieldProto
UNKNOWN_FIELD: FieldProto

class FieldProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
