# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/models/security/coupon_frequency.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1fintekkers/models/security/coupon_frequency.proto\x12\x1a\x66intekkers.models.security*\x7f\n\x14\x43ouponFrequencyProto\x12\x1c\n\x18UNKNOWN_COUPON_FREQUENCY\x10\x00\x12\x0c\n\x08\x41NNUALLY\x10\x01\x12\x10\n\x0cSEMIANNUALLY\x10\x02\x12\r\n\tQUARTERLY\x10\x03\x12\x0b\n\x07MONTHLY\x10\x04\x12\r\n\tNO_COUPON\x10\x05\x42\x19\x42\x15\x43ouponFrequencyProtosP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.security.coupon_frequency_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\025CouponFrequencyProtosP\001'
  _COUPONFREQUENCYPROTO._serialized_start=81
  _COUPONFREQUENCYPROTO._serialized_end=208
# @@protoc_insertion_point(module_scope)
